"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Block;

var _md = _interopRequireDefault(require("md5"));

var _guid = _interopRequireDefault(require("./support/guid"));

var _torchlight = _interopRequireDefault(require("./torchlight"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Block(opts = {}) {
  opts = {
    id: (0, _guid.default)(),
    theme: _torchlight.default.config('theme', 'nord'),
    ...opts
  };
  this.id = opts.id;
  this.code = opts.code;
  this.language = opts.language;
  this.theme = opts.theme;
  this.highlighted = null;
  this.classes = null;
  this.styles = null;
}

Block.prototype.hash = function () {
  return (0, _md.default)('' + this.language + this.theme + this.code + _torchlight.default.config('bust', 0) + JSON.stringify(_torchlight.default.config('options')));
};

Block.prototype.code = function (code) {
  this.code = code;
  return this;
};

Block.prototype.language = function (language) {
  this.language = language;
  return this;
};

Block.prototype.theme = function (theme) {
  this.theme = theme;
  return this;
};

Block.prototype.placeholder = function (extra = '') {
  if (extra) {
    extra = `-${extra}`;
  }

  return `__torchlight-block-[${this.id}]${extra}__`;
};

Block.prototype.setResponseData = function (data) {
  if (data) {
    this.highlighted = data.highlighted;
    this.classes = data.classes;
    this.styles = data.styles;
  }

  return this;
};

Block.prototype.toRequestParams = function () {
  return {
    id: this.id,
    hash: this.hash,
    language: this.language,
    theme: this.theme,
    code: this.code
  };
};