"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = File;

var _md = _interopRequireDefault(require("md5"));

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @param options
 * @constructor
 */
function File(options = {}) {
  if (!options.directory) {
    throw new Error('No cache directory specified.');
  }

  this.directory = _path.default.resolve(options.directory);

  _fsExtra.default.ensureDirSync(this.directory);
}
/**
 * Get an item from the cache.
 *
 * @param {string} key
 * @param {*} def
 * @return {*}
 */


File.prototype.get = function (key, def) {
  if (!_fsExtra.default.pathExistsSync(this.filename(key))) {
    return def;
  }

  const entry = _fsExtra.default.readJsonSync(this.filename(key));

  if (Date.now() / 1000 > entry.expires) {
    this.delete(key);
    return def;
  }

  return entry.value;
};
/**
 * Set an item in the cache.
 *
 * @param {string} key
 * @param {*} value
 * @param {number} ttlSeconds
 */


File.prototype.set = function (key, value, ttlSeconds = 60 * 24 * 7) {
  _fsExtra.default.writeJsonSync(this.filename(key), {
    expires: Date.now() / 1000 + ttlSeconds,
    value: value
  });
};
/**
 * Remove a key from the cache.
 *
 * @param key
 */


File.prototype.delete = function (key) {
  _fsExtra.default.removeSync(this.filename(key));
};
/**
 * Clear the cache.
 */


File.prototype.clear = function () {
  _fsExtra.default.removeSync(this.directory);
};
/**
 * @param {string} key
 * @return {string}
 */


File.prototype.filename = function (key) {
  return _path.default.join(this.directory, (0, _md.default)(key) + '.json');
};