"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeConfig = makeConfig;
exports.makeCache = makeCache;

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _path = _interopRequireDefault(require("path"));

var _file = _interopRequireDefault(require("./cache/file"));

var _memory = _interopRequireDefault(require("./cache/memory"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @param {string|object} config
 * @return {*}
 */
function makeConfig(config) {
  // By convention, look in the root directory for
  // a torchlight.config.js file.
  if (config === undefined || config === '') {
    config = 'torchlight.config.js';
  }

  if (typeof config === 'string') {
    config = _fsExtra.default.pathExistsSync(_path.default.resolve(config)) ? require(_path.default.resolve(config)) : {};
  }

  return config || {};
}
/**
 * Make a cache to hold highlighted blocks.
 *
 * @return {Cache}
 */


function makeCache(config) {
  const cache = config === null || config === void 0 ? void 0 : config.cache; // Make a file cache if we're given a directory.

  if (cache && typeof cache === 'string') {
    return new _file.default({
      directory: cache
    });
  } // Use the cache they have provided, or default to an in-memory cache.


  return cache || new _memory.default();
}